==========
 Glossary
==========

This is a glossary for some definitions used in this documentation and
still heavily under construction.

.. glossary:: :sorted:

    Plone Intranet 
        The name of an initiative of several Plone companies trying to increase cohesion and consolidate efforts to create a common intranet solution based on Plone.

